@@ -58,8 +58,6 @@ pub enum Card {
     },
     /// Single card that decomposes into multiple cards
     CompositeCard(Box<CompositeCard>),
-    /// Does nothing
-    Noop,
 }
 
 impl Card {
@@ -103,7 +101,6 @@ impl Card {
             Card::SetProperty => "SetProperty",
             Card::ForEach { .. } => "ForEach",
             Card::CompositeCard(c) => c.name.as_str(),
-            Card::Noop => "No-op",
         }
     }
 
@@ -117,8 +114,8 @@ impl Card {
             | Card::While(_)
             | Card::Repeat(_)
             | Card::ForEach { .. }
-            | Card::CompositeCard { .. }
-            | Card::Noop => None,
+            | Card::Pass
+            | Card::CompositeCard { .. } => None,
 
             Card::GetProperty => Some(Instruction::GetProperty),
             Card::SetProperty => Some(Instruction::SetProperty),
@@ -128,7 +125,6 @@ impl Card {
             Card::Not => Some(Instruction::Not),
             Card::Or => Some(Instruction::Or),
             Card::Xor => Some(Instruction::Xor),
-            Card::Pass => Some(Instruction::Pass),
             Card::Add => Some(Instruction::Add),
             Card::Sub => Some(Instruction::Sub),
             Card::Mul => Some(Instruction::Mul),
@@ -197,8 +193,7 @@ impl Card {
             | Instruction::Repeat
             | Instruction::BeginRepeat
             | Instruction::ForEach
-            | Instruction::BeginForEach
-            | Instruction::Pass => {}
+            | Instruction::BeginForEach => {}
         };
     }
 
@@ -319,13 +314,13 @@ impl Card {
                 if i != 0 {
                     return None;
                 }
-                res = std::mem::replace::<Card>(c.as_mut(), Card::Noop);
+                res = std::mem::replace::<Card>(c.as_mut(), Card::Pass);
             }
             Card::IfElse { then, r#else } => {
                 if i > 1 {}
                 match i {
-                    0 => res = std::mem::replace::<Card>(then.as_mut(), Card::Noop),
-                    1 => res = std::mem::replace::<Card>(r#else.as_mut(), Card::Noop),
+                    0 => res = std::mem::replace::<Card>(then.as_mut(), Card::Pass),
+                    1 => res = std::mem::replace::<Card>(r#else.as_mut(), Card::Pass),
                     _ => return None,
                 }
             }
