@@ -407,13 +407,5 @@ Order of parameters: Table, Property-Key, Value"#,
             []
         ),
 
-        Card::Noop => subprogram_description!(
-            "No-op",
-            "Does nothing",
-            SubProgramType::Instruction,
-            [],
-            [],
-            []
-        ),
     }
 }
