@@ -1,6 +1,7 @@
 pub use crate::compiled_program::*;
 pub use crate::compiler::{
-    compile, CaoProgram, Card, CompilationError, CompilationErrorPayload, CompileOptions, Lane,
+    compile, CaoProgram, Card, CardIndex, CompilationError, CompilationErrorPayload,
+    CompileOptions, Lane,
 };
 pub use crate::procedures::*;
 pub use crate::traits::*;
@@ -9,5 +10,5 @@ pub use crate::{
     collections::key_map::Handle,
     subprogram_description,
     vm::{runtime::FieldTable, Vm},
-    InputString, NodeId, StrPointer, SubProgramDescription, SubProgramType,
+    InputString, StrPointer, SubProgramDescription, SubProgramType,
 };
