@@ -199,7 +199,7 @@ impl<'a, Aux> Vm<'a, Aux> {
                 stack_offset: 0,
             })
             .map_err(|_| ExecutionErrorPayload::CallStackOverflow)
-            .map_err(|pl| ExecutionError::new(pl, TraceEntry::default()))?;
+            .map_err(|pl| ExecutionError::new(pl, CardIndex::default()))?;
 
         let len = program.bytecode.len();
         let mut remaining_iters = self.max_instr;
@@ -383,7 +383,6 @@ impl<'a, Aux> Vm<'a, Aux> {
                     instr_execution::instr_copy_last(self)
                         .map_err(|err| payload_to_error(err, instr_ptr))?;
                 }
-                Instruction::Pass => {}
                 Instruction::ScalarInt => {
                     self.runtime_data
                         .value_stack
